pub struct MaskHandle { /* private fields */ }Expand description
Processed mask image with optional further refinement and output generation.
Represents a concrete mask image (typically binary after thresholding) produced by executing
operations from a MatteHandle.
Example
use outline::{Outline, VtracerSvgVectorizer, TraceOptions};
let outline = Outline::new("model.onnx");
let session = outline.for_image("input.jpg")?;
let mask = session.matte().blur().threshold().processed()?;
// Generate multiple outputs from the mask
mask.save("mask.png")?;
mask.foreground()?.save("subject.png")?;
let vectorizer = VtracerSvgVectorizer;
let svg = mask.trace(&vectorizer, &TraceOptions::default())?;
std::fs::write("outline.svg", svg)?;Implementations
Sourceimpl MaskHandle
impl MaskHandle
Sourcepub fn into_image(self) -> GrayImage
pub fn into_image(self) -> GrayImage
Consume the handle and return the mask.
Sourcepub fn save(&self, path: impl AsRef<Path>) -> OutlineResult<()>
pub fn save(&self, path: impl AsRef<Path>) -> OutlineResult<()>
Save the mask to the specified path.
Sourcepub fn threshold_with(self, value: u8) -> Self
pub fn threshold_with(self, value: u8) -> Self
Add a threshold operation with a custom value.
Sourcepub fn dilate(self) -> Self
pub fn dilate(self) -> Self
Add a dilation operation using the default radius.
Note: Dilation typically works best on binary masks. If this mask is still grayscale,
consider calling threshold first.
Sourcepub fn dilate_with(self, radius: f32) -> Self
pub fn dilate_with(self, radius: f32) -> Self
Add a dilation operation with a custom radius.
Note: Dilation typically works best on binary masks. If this mask is still grayscale,
consider calling threshold first.
Sourcepub fn fill_holes(self) -> Self
pub fn fill_holes(self) -> Self
Add a hole-filling operation to the processing pipeline.
Note: Hole-filling typically works best on binary masks. If this mask is still grayscale,
consider calling threshold first.
Sourcepub fn processed(self) -> OutlineResult<MaskHandle>
pub fn processed(self) -> OutlineResult<MaskHandle>
Process the mask with the accumulated operations and default options.
Sourcepub fn processed_with(
self,
options: &MaskProcessingOptions,
) -> OutlineResult<MaskHandle>
pub fn processed_with( self, options: &MaskProcessingOptions, ) -> OutlineResult<MaskHandle>
Process the mask with the accumulated operations and custom options.
Sourcepub fn foreground(&self) -> OutlineResult<ForegroundHandle>
pub fn foreground(&self) -> OutlineResult<ForegroundHandle>
Compose the RGBA foreground image from the RGB image and the current mask.
Sourcepub fn trace<V>(
&self,
vectorizer: &V,
options: &V::Options,
) -> OutlineResult<V::Output>where
V: MaskVectorizer,
pub fn trace<V>(
&self,
vectorizer: &V,
options: &V::Options,
) -> OutlineResult<V::Output>where
V: MaskVectorizer,
Trace the current mask using the specified vectorizer and options.